import argparse
import asyncio
import signal
import threading
from http.server import HTTPServer, SimpleHTTPRequestHandler

import socketio

from .decorator import register_service
from .get_ip import get_ip_address


def start_client(host_ip="0.0.0.0", host_port=4999):
    @register_service(
        name="test client",
        ip=get_ip_address(),
        port=13373,
        host_ip=host_ip,
        host_port=host_port,
    )
    def server(port=13373):
        httpd = HTTPServer(("", port), SimpleHTTPRequestHandler)
        print(f"Serving HTTP on 0.0.0.0 port {port} (http://0.0.0.0:{port}/) ...")

        def serve_forever_nonblocking():
            httpd.serve_forever()

        server_thread = threading.Thread(target=serve_forever_nonblocking)
        server_thread.start()

        return server_thread

    try:
        server_thread = server()
        while True:
            pass
    except (KeyboardInterrupt, asyncio.exceptions.CancelledError):
        print("Cleaning up and shutting down...")
        # server_thread.join()
    finally:
        print("Shutting down test client...")


if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Start announce_server client.")
    parser.add_argument(
        "--host-ip",
        type=str,
        default="0.0.0.0",
        help="Host IP address (default: 0.0.0.0)",
    )
    parser.add_argument(
        "--host-port", type=int, default=4999, help="Host port number (default: 4999)"
    )
    args = parser.parse_args()

    start_client(args.host_ip, args.host_port)
